@@ -1,4 +1,5 @@
 import os
+import logging
 import pkg_resources
 
 class Recipe:
@@ -9,6 +10,7 @@ class Recipe:
         options.setdefault('eggs', '')
 
     def install(self):
+        log = logging.getLogger(self.name)
         eggs = self.options['eggs']
         eggs = eggs.split('\n')
         
@@ -22,9 +24,9 @@ class Recipe:
                 f = open(egg_egg_link, 'w')
                 f.write(dist.location)
                 f.close()
-                print 'Using %s for %s' % (dist.location, egg)
+                log.info('Using %s for %s' % (dist.location, egg))
             except pkg_resources.DistributionNotFound:
-                print 'No system distribution for %s found.' % egg
+                log.warn('No system distribution for %s found.' % egg)
         return ()
 
     update = install
\ No newline at end of file
